@@ -4,19 +4,24 @@ use strict;
 use warnings;
 use File::Spec;
 use ExtUtils::CBuilder;
+use FindBin ();
+use Alien::FFI;
 use File::Copy qw( move );
 use File::Glob qw( bsd_glob );
 use Config;
 use Text::ParseWords qw( shellwords );
 
+my $root = $FindBin::Bin;
+
 sub build
 {
-  # $b isa ExtUtils::CBuilder
-  my(undef, $b, $ccflags, $extra_compiler_flags, $extra_linker_flags) = @_;
+  my $mb = shift;
 
   my($header_time) = reverse sort map { (stat $_)[9] } bsd_glob "include/*.h";
   my $compile_count = 0;
   
+  my $b = ExtUtils::CBuilder->new;
+  
   my @obj = map {
     my $filename = $_;
     my($source_time) = reverse sort ((stat $filename)[9], $header_time);
@@ -27,41 +32,30 @@ sub build
       $b->compile(
         source => $filename,
         include_dirs => [
-          'include',
+          File::Spec->catdir($root, 'include'),
         ],
-        extra_compiler_flags => $extra_compiler_flags,
+        extra_compiler_flags => Alien::FFI->cflags,
       );
       $compile_count++;
     }
     $obj_name;
-  } bsd_glob("t/ffi/*.c");
+  } bsd_glob("libtest/*.c");
   
   return unless $compile_count > 0;
   
   if($^O ne 'MSWin32')
   {
     my $dll = $b->link(
-      lib_file           => $b->lib_file(File::Spec->catfile('t/ffi', $b->object_file('libtest.c'))),
-      objects            => \@obj,
-      extra_linker_flags => $extra_linker_flags,
+      lib_file => $b->lib_file(File::Spec->catfile($root, 'libtest', $b->object_file('libtest.c'))),
+      objects  => \@obj,
+      extra_linker_flags => Alien::FFI->libs,
     );
     
-    if($^O =~ /^(cygwin|msys)$/)
+    if($^O eq 'cygwin')
     {
       my $old = $dll;
       my $new = $dll;
-      if($^O eq 'cygwin')
-      {
-        $new =~ s{libtest.dll$}{cygtest-1.dll};
-      }
-      elsif($^O eq 'msys')
-      {
-        $new =~ s{libtest.dll$}{msys-test-1.dll};
-      }
-      else
-      {
-        die "how?";
-      }
+      $new =~ s{libtest.dll$}{cygtest-1.dll};
       move($old => $new) || die "unable to copy $old => $new $!";
     }
   }
@@ -69,7 +63,7 @@ sub build
   {
     # On windows we can't depend on MM::CBuilder to make the .dll file because it creates dlls
     # that export only one symbol (which is used for bootstrapping XS modules).
-    my $dll = File::Spec->catfile('t/ffi', 'libtest.dll');
+    my $dll = File::Spec->catfile($FindBin::Bin, 'libtest', 'libtest.dll');
     $dll =~ s{\\}{/}g;
     my @cmd;
     my $cc = $Config{cc};
@@ -83,7 +77,7 @@ sub build
     {
       @cmd = ($cc, @obj, '/link', '/dll', '/out:' . $dll);
     }
-    print "@cmd\n";
+    print "@cmd";
     system @cmd;
     exit 2 if $?;
   }
