@@ -8,7 +8,7 @@ use base qw( Exporter );
 our @EXPORT = grep /^arguments_/, keys %FFI::Platypus::API::;
 
 # ABSTRACT: Platypus arguments and return value API for custom types
-our $VERSION = '0.99_06'; # TRIAL VERSION
+our $VERSION = '0.12'; # VERSION
 
 
 1;
@@ -25,7 +25,7 @@ FFI::Platypus::API - Platypus arguments and return value API for custom types
 
 =head1 VERSION
 
-version 0.99_06
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -50,19 +50,13 @@ version 0.99_06
 
 =head1 DESCRIPTION
 
-B<NOTE>: I added this interface early on to L<FFI::Platypus>, but haven't
-used it much, generally finding function wrappers to be a more powerful
-(although possibly not as fast) interface.  It has thus not been
-tested as much as the rest of Platypus.  If you feel the need to use
-this interface please coordinate with the Platypus developers.
-
-The custom types API for L<FFI::Platypus> allows you to set multiple C
-arguments from a single Perl argument as a common type.  This is
-sometimes useful for pointer / size pairs which are a common pattern in
-C, but are usually represented by a single value (a string scalar) in
+The custom types API for L<FFI::Platypus> allows you to set multiple C 
+arguments from a single Perl argument as a common type.  This is 
+sometimes useful for pointer / size pairs which are a common pattern in 
+C, but are usually represented by a single value (a string scalar) in 
 Perl.
 
-The custom type API is somewhat experimental, and you should expect some
+The custom type API is somewhat experimental, and you should expect some 
 changes as needs arise (I won't break compatibility lightly, however).
 
 =head1 FUNCTIONS
@@ -193,7 +187,7 @@ Get the double precision floating point argument from position I<$i>.
 
  arguments_set_double $i, $double;
 
-Set the double precision floating point argument at position I<$i> to
+Set the double precision floating point argument at position I<$i> to 
 I<$double>
 
 =head2 arguments_get_pointer
@@ -238,41 +232,11 @@ Examples of use:
 
 =head1 AUTHOR
 
-Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
-
-Contributors:
-
-Bakkiaraj Murugesan (bakkiaraj)
-
-Dylan Cali (calid)
-
-pipcet
-
-Zaki Mughal (zmughal)
-
-Fitz Elliott (felliott)
-
-Vickenty Fesunov (vyf)
-
-Gregor Herrmann (gregoa)
-
-Shlomi Fish (shlomif)
-
-Damyan Ivanov
-
-Ilya Pavlov (Ilya33)
-
-Petr Pisar (ppisar)
-
-Mohammad S Anwar (MANWAR)
-
-Håkon Hægland (hakonhagland, HAKONH)
-
-Meredith (merrilymeredith, MHOWARD)
+Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015,2016,2017,2018,2019 by Graham Ollis.
+This software is copyright (c) 2015 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
