@@ -3,7 +3,7 @@ package FFI::Platypus::Type::PointerSizeBuffer;
 use strict;
 use warnings;
 use FFI::Platypus;
-use FFI::Platypus::API qw(
+use FFI::Platypus::API qw( 
   arguments_set_pointer
   arguments_set_uint32
   arguments_set_uint64
@@ -12,13 +12,13 @@ use FFI::Platypus::Buffer qw( scalar_to_buffer );
 use FFI::Platypus::Buffer qw( buffer_to_scalar );
 
 # ABSTRACT: Convert string scalar to a buffer as a pointer / size_t combination
-our $VERSION = '0.99_06'; # TRIAL VERSION
+our $VERSION = '0.12'; # VERSION
 
 
 my @stack;
 
-*arguments_set_size_t
-  = FFI::Platypus->new( api => 1 )->sizeof('size_t') == 4
+*arguments_set_size_t 
+  = FFI::Platypus->new->sizeof('size_t') == 4
   ? \&arguments_set_uint32
   : \&arguments_set_uint64;
 
@@ -60,7 +60,7 @@ FFI::Platypus::Type::PointerSizeBuffer - Convert string scalar to a buffer as a
 
 =head1 VERSION
 
-version 0.99_06
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -74,21 +74,20 @@ In your C code:
 
 In your Platypus::FFI code:
 
- use FFI::Platypus;
+ use FFI::Platypus::Declare
+   'void',
+   [ '::PointerSizeBuffer' => 'buffer' ];
  
- my $ffi = FFI::Platypus->new( api => 1 );
- $ffi->load_custom_type('::PointerSizeBuffer' => 'buffer');
- 
- $ffi->attach(function_with_buffer => ['buffer'] => 'void');
+ attach function_with_buffer => [buffer] => void;
  my $string = "content of buffer";
  function_with_buffer($string);
 
 =head1 DESCRIPTION
 
-A common pattern in C code is to pass in a region of memory as a buffer,
-consisting of a pointer and a size of the memory region.  In Perl,
-string scalars also point to a contiguous series of bytes that has a
-size, so when interfacing with C libraries it is handy to be able to
+A common pattern in C code is to pass in a region of memory as a buffer, 
+consisting of a pointer and a size of the memory region.  In Perl, 
+string scalars also point to a contiguous series of bytes that has a 
+size, so when interfacing with C libraries it is handy to be able to 
 pass in a string scalar as a pointer / size buffer pair.
 
 =head1 SEE ALSO
@@ -99,49 +98,25 @@ pass in a string scalar as a pointer / size buffer pair.
 
 Main Platypus documentation.
 
+=item L<FFI::Platypus::Declare>
+
+Declarative interface for Platypus.
+
 =item L<FFI::Platypus::Type>
 
 Platypus types documentation.
 
 =back
 
+=cut
+
 =head1 AUTHOR
 
-Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
-
-Contributors:
-
-Bakkiaraj Murugesan (bakkiaraj)
-
-Dylan Cali (calid)
-
-pipcet
-
-Zaki Mughal (zmughal)
-
-Fitz Elliott (felliott)
-
-Vickenty Fesunov (vyf)
-
-Gregor Herrmann (gregoa)
-
-Shlomi Fish (shlomif)
-
-Damyan Ivanov
-
-Ilya Pavlov (Ilya33)
-
-Petr Pisar (ppisar)
-
-Mohammad S Anwar (MANWAR)
-
-Håkon Hægland (hakonhagland, HAKONH)
-
-Meredith (merrilymeredith, MHOWARD)
+Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015,2016,2017,2018,2019 by Graham Ollis.
+This software is copyright (c) 2015 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
