@@ -3,18 +3,17 @@ package FFI::Platypus::Type::StringPointer;
 use strict;
 use warnings;
 use FFI::Platypus;
-use Scalar::Util qw( readonly );
 use Config ();
 
 # ABSTRACT: Convert a pointer to a string and back
-our $VERSION = '0.99_06'; # TRIAL VERSION
+our $VERSION = '0.12'; # VERSION
 
 
 use constant _incantation =>
   $^O eq 'MSWin32' && $Config::Config{archname} =~ /MSWin32-x64/
   ? 'Q'
   : 'L!';
-use constant _pointer_buffer => "P" . FFI::Platypus->new( api => 1 )->sizeof('opaque');
+use constant _pointer_buffer => "P" . FFI::Platypus->new->sizeof('opaque');
 
 my @stack;
 
@@ -39,10 +38,11 @@ sub perl_to_native_post
 {
   my($packed) = @{ pop @stack };
   return unless defined $packed;
-  unless(readonly(${$_[0]}))
-  {
-    ${$_[0]} = unpack 'p', $$packed;
-  }
+  # TODO: doing an eval here to ignore ro value
+  # modification.  Can we instead check for
+  # ro on the scalar and if so would that be
+  # faster than the eval
+  eval { ${$_[0]} = unpack 'p', $$packed };
 }
 
 sub native_to_perl
@@ -76,7 +76,7 @@ FFI::Platypus::Type::StringPointer - Convert a pointer to a string and back
 
 =head1 VERSION
 
-version 0.99_06
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -95,13 +95,12 @@ In your C code:
 
 In your Platypus::FFI code:
 
- use FFI::Platypus;
+ use FFI::Platypus::Declare
+   'void',
+   [ '::StringPointer' => 'string_pointer' ];
  
- my $ffi = FFI::Platypus->new( api => 1 );
- $ffi->load_custom_type('::StringPointer' => 'string_pointer');
- 
- $ffi->attach(string_pointer_argument => ['string_pointer'] => 'void');
- $ffi->attach(string_pointer_return   => [] => 'string_pointer');
+ attach string_pointer_argument => [string_pointer] => void;
+ attach string_pointer_return   => [] => string_pointer;
  
  my $string = "foo";
  
@@ -113,10 +112,6 @@ In your Platypus::FFI code:
 
 =head1 DESCRIPTION
 
-B<NOTE>: As of version 0.61, this custom type is now deprecated since
-pointers to strings are supported in the L<FFI::Platypus> directly
-without custom types.
-
 This module provides a L<FFI::Platypus> custom type for pointers to
 strings.
 
@@ -128,49 +123,25 @@ strings.
 
 Main Platypus documentation.
 
+=item L<FFI::Platypus::Declare>
+
+Declarative interface for Platypus.
+
 =item L<FFI::Platypus::Type>
 
 Platypus types documentation.
 
 =back
 
+=cut
+
 =head1 AUTHOR
 
-Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
-
-Contributors:
-
-Bakkiaraj Murugesan (bakkiaraj)
-
-Dylan Cali (calid)
-
-pipcet
-
-Zaki Mughal (zmughal)
-
-Fitz Elliott (felliott)
-
-Vickenty Fesunov (vyf)
-
-Gregor Herrmann (gregoa)
-
-Shlomi Fish (shlomif)
-
-Damyan Ivanov
-
-Ilya Pavlov (Ilya33)
-
-Petr Pisar (ppisar)
-
-Mohammad S Anwar (MANWAR)
-
-Håkon Hægland (hakonhagland, HAKONH)
-
-Meredith (merrilymeredith, MHOWARD)
+Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015,2016,2017,2018,2019 by Graham Ollis.
+This software is copyright (c) 2015 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
